@@ -17,4 +17,8 @@ class benefits(Variable):
         "on_benefits",
         # British Columbia programs.
         "bc_benefits",
+        # New Brunswick programs.
+        "nb_benefits",
+        # Saskatchewan programs.
+        "sk_benefits",
     ]
