@@ -4,7 +4,7 @@ from policyengine_canada.model_api import *
 class climate_action_incentive(Variable):
     value_type = float
     entity = Household
-    label = "Canada Climate Action Incentive after rural supplement"
+    label = "Climate action incentive payment"
     unit = CAD
     documentation = "Universal amount without adjustment based on AFNI"
     definition_period = YEAR
