@@ -8,9 +8,9 @@ class is_child_for_gst_credit(Variable):
     definition_period = YEAR
 
     def formula(person, period, parameters):
-        dependent = person("is_dependent", period)
+        dependant = person("is_dependant", period)
         age = person("age", period)
         adult_age = parameters(
             period
         ).gov.cra.tax.income.credits.gst_credit.adult_age
-        return dependent & (age < adult_age)
+        return dependant & (age < adult_age)
