@@ -3,7 +3,7 @@ from policyengine_canada.model_api import *
 
 class non_refundable_tax_credits(Variable):
     value_type = float
-    entity = Household
+    entity = Person
     label = "Non-refundable tax credits"
     unit = CAD
     definition_period = YEAR
