@@ -4,8 +4,7 @@ from policyengine_canada.model_api import *
 class bc_non_refundable_credits(Variable):
     value_type = float
     entity = Person
-    label = "BC non-refundable credits"
-    documentation = "British Columbia non-refundable tax credits"
+    label = "British Columbia non-refundable credits"
     unit = CAD
     definition_period = YEAR
     defined_for = ProvinceCode.BC
