@@ -4,7 +4,7 @@ from policyengine_canada.model_api import *
 class bc_climate_action_tax_credit(Variable):
     value_type = float
     entity = Household
-    label = "British Columbia climate action tax credit after reduction"
+    label = "British Columbia climate action tax credit"
     unit = CAD
     documentation = "Universal amount without adjustment based on AFNI"
     definition_period = YEAR
