@@ -15,15 +15,14 @@ class on_child_benefit(Variable):
     def formula(household, period, parameters):
         base = household("on_child_benefit_base", period)
         reduction = household("on_child_benefit_reduction", period)
-        devsior = parameters(
+        shared_custody_divisor = parameters(
             period
         ).gov.provinces.on.benefits.ocb.shared_custody_divisor
         has_any_full_custody_children = (
             add(household, period, ["full_custody"]) > 0
         )
-        child_benefit_amount = max_(0, base - reduction)
-        return where(
-            has_any_full_custody_children,
-            child_benefit_amount,
-            child_benefit_amount / devsior,
+        divisor = where(
+            has_any_full_custody_children, 1, shared_custody_divisor
         )
+        child_benefit_amount = max_(0, base - reduction)
+        return child_benefit_amount / divisor
