@@ -7,12 +7,10 @@ class on_senior_homeowners_property_tax_grant_base(Variable):
     label = "Ontario senior homeowners property tax grant base"
     unit = CAD
     definition_period = YEAR
+    defined_for = ProvinceCode.ONT
 
     def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_ontario = province == province.possible_values.ONTARIO
         p = parameters(period).gov.provinces.on.tax.grants.oshptg
         age_eligible = person("age", period) >= p.age_eligibility
-        eligible = age_eligible & in_ontario
         amount_if_eligible = min_(person("property_tax", period), p.max_amount)
-        return eligible * amount_if_eligible
+        return age_eligible * amount_if_eligible
