@@ -8,10 +8,9 @@ class on_income_tax_before_credits(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.canada.ca/en/revenue-agency/services/tax/individuals/frequently-asked-questions-individuals/canadian-income-tax-rates-individuals-current-previous-years.html"
+    defined_for = ProvinceCode.ONT
 
     def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_ontario = province == province.possible_values.ONTARIO
         income = person("on_taxable_income", period)
         p = parameters(period).gov.provinces.on.tax.income.rate
-        return in_ontario * p.calc(income)
+        return p.calc(income)
