@@ -8,10 +8,9 @@ class pe_income_tax_before_credits(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.canada.ca/en/revenue-agency/services/tax/individuals/frequently-asked-questions-individuals/canadian-income-tax-rates-individuals-current-previous-years.html"
+    defined_for = ProvinceCode.PE
 
     def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_pe = province == province.possible_values.PRINCE_EDWARD_ISLAND
         income = person("pe_taxable_income", period)
         p = parameters(period).gov.provinces.pe.tax.income.rate
-        return in_pe * p.calc(income)
+        return p.calc(income)
