@@ -8,10 +8,9 @@ class yt_income_tax_before_credits(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.canada.ca/en/revenue-agency/services/tax/individuals/frequently-asked-questions-individuals/canadian-income-tax-rates-individuals-current-previous-years.html"
+    defined_for = ProvinceCode.YT
 
     def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_yukon = province == province.possible_values.YUKON
         income = person("yt_taxable_income", period)
         p = parameters(period).gov.provinces.yt.tax.income.rate
-        return in_yukon * p.calc(income)
+        return p.calc(income)
